@@ -7,7 +7,7 @@ from StringIO import StringIO
 from urlparse import urlparse
 from utils import json_to_py, get_faker
 
-__version_info__ = ('2', '4', '1')
+__version_info__ = ('2', '5', '0')
 __version__ = '.'.join(__version_info__)
 
 class CreateSendError(Exception):
@@ -125,7 +125,12 @@ class CreateSend(CreateSendBase):
     """Gets your clients."""
     response = self._get('/clients.json')
     return json_to_py(response)
-    
+
+  def billing_details(self):
+    """Gets your billing details."""
+    response = self._get('/billingdetails.json')
+    return json_to_py(response)
+
   def countries(self):
     """Gets valid countries."""
     response = self._get('/countries.json')
