@@ -85,7 +85,7 @@ class List(CreateSendBase):
     response = self._get(self.uri_for("stats"))
     return json_to_py(response)
 
-  def active(self, date, page=1, page_size=1000, order_field="email", order_direction="asc"):
+  def active(self, date="", page=1, page_size=1000, order_field="email", order_direction="asc"):
     """Gets the active subscribers for this list."""
     params = {
       "date": date,
@@ -96,7 +96,7 @@ class List(CreateSendBase):
     response = self._get(self.uri_for("active"), params=params)
     return json_to_py(response)
 
-  def unconfirmed(self, date, page=1, page_size=1000, order_field="email", order_direction="asc"):
+  def unconfirmed(self, date="", page=1, page_size=1000, order_field="email", order_direction="asc"):
     """Gets the unconfirmed subscribers for this list."""
     params = {
       "date": date,
@@ -107,7 +107,7 @@ class List(CreateSendBase):
     response = self._get(self.uri_for("unconfirmed"), params=params)
     return json_to_py(response)
 
-  def bounced(self, date, page=1, page_size=1000, order_field="email", order_direction="asc"):
+  def bounced(self, date="", page=1, page_size=1000, order_field="email", order_direction="asc"):
     """Gets the bounced subscribers for this list."""
     params = {
       "date": date,
@@ -118,7 +118,7 @@ class List(CreateSendBase):
     response = self._get(self.uri_for("bounced"), params=params)
     return json_to_py(response)
 
-  def unsubscribed(self, date, page=1, page_size=1000, order_field="email", order_direction="asc"):
+  def unsubscribed(self, date="", page=1, page_size=1000, order_field="email", order_direction="asc"):
     """Gets the unsubscribed subscribers for this list."""
     params = {
       "date": date,
@@ -129,7 +129,7 @@ class List(CreateSendBase):
     response = self._get(self.uri_for("unsubscribed"), params=params)
     return json_to_py(response)
 
-  def deleted(self, date, page=1, page_size=1000, order_field="email", order_direction="asc"):
+  def deleted(self, date="", page=1, page_size=1000, order_field="email", order_direction="asc"):
     """Gets the deleted subscribers for this list."""
     params = {
       "date": date,
