@@ -22,6 +22,7 @@ class ClientTestCase(unittest.TestCase):
     self.assertEquals(cl.BasicDetails.ContactName, "Client One (contact)")
     self.assertEquals(cl.AccessDetails.Username, "clientone")
     self.assertEquals(cl.AccessDetails.AccessLevel, 23)
+    self.assertEquals(cl.BillingDetails.Credits, 500)
 
   def test_campaigns(self):
     self.cl.stub_request("clients/%s/campaigns.json" % self.cl.client_id, "campaigns.json")
@@ -29,10 +30,14 @@ class ClientTestCase(unittest.TestCase):
     self.assertEquals(len(campaigns), 2)
     self.assertEquals(campaigns[0].CampaignID, 'fc0ce7105baeaf97f47c99be31d02a91')
     self.assertEquals(campaigns[0].WebVersionURL, 'http://createsend.com/t/r-765E86829575EE2C')
+    self.assertEquals(campaigns[0].WebVersionTextURL, 'http://createsend.com/t/r-765E86829575EE2C/t')
     self.assertEquals(campaigns[0].Subject, 'Campaign One')
     self.assertEquals(campaigns[0].Name, 'Campaign One')
     self.assertEquals(campaigns[0].SentDate, '2010-10-12 12:58:00')
     self.assertEquals(campaigns[0].TotalRecipients, 2245)
+    self.assertEquals(campaigns[0].FromName, 'My Name')
+    self.assertEquals(campaigns[0].FromEmail, 'myemail@example.com')
+    self.assertEquals(campaigns[0].ReplyTo, 'myemail@example.com')
 
   def test_scheduled(self):
     self.cl.stub_request("clients/%s/scheduled.json" % self.cl.client_id, "scheduled_campaigns.json")
@@ -45,6 +50,10 @@ class ClientTestCase(unittest.TestCase):
     self.assertEquals(campaigns[0].Subject, "Magic Issue One")
     self.assertEquals(campaigns[0].DateCreated, "2011-05-24 10:37:00")
     self.assertEquals(campaigns[0].PreviewURL, "http://createsend.com/t/r-DD543521A87C9B8B")
+    self.assertEquals(campaigns[0].PreviewTextURL, "http://createsend.com/t/r-DD543521A87C9B8B/t")
+    self.assertEquals(campaigns[0].FromName, 'My Name')
+    self.assertEquals(campaigns[0].FromEmail, 'myemail@example.com')
+    self.assertEquals(campaigns[0].ReplyTo, 'myemail@example.com')
 
   def test_drafts(self):
     self.cl.stub_request("clients/%s/drafts.json" % self.cl.client_id, "drafts.json")
@@ -55,6 +64,10 @@ class ClientTestCase(unittest.TestCase):
     self.assertEquals(drafts[0].Subject, 'Draft One')
     self.assertEquals(drafts[0].DateCreated, '2010-08-19 16:08:00')
     self.assertEquals(drafts[0].PreviewURL, 'http://createsend.com/t/r-E97A7BB2E6983DA1')
+    self.assertEquals(drafts[0].PreviewTextURL, 'http://createsend.com/t/r-E97A7BB2E6983DA1/t')
+    self.assertEquals(drafts[0].FromName, 'My Name')
+    self.assertEquals(drafts[0].FromEmail, 'myemail@example.com')
+    self.assertEquals(drafts[0].ReplyTo, 'myemail@example.com')
 
   def test_lists(self):
     self.cl.stub_request("clients/%s/lists.json" % self.cl.client_id, "lists.json")
@@ -136,14 +149,20 @@ class ClientTestCase(unittest.TestCase):
   def test_set_monthly_billing_unlimited(self):
     self.cl.stub_request("clients/%s/setmonthlybilling.json" % self.cl.client_id, None, None, "{\"Currency\": \"CAD\", \"MonthlyScheme\": \"Unlimited\", \"MarkupPercentage\": 100, \"ClientPays\": true}")
     self.cl.set_monthly_billing("CAD", True, 100, "Unlimited")
-        
+
+  def test_transfer_credits(self):
+    self.cl.stub_request("clients/%s/credits.json" % self.cl.client_id, "transfer_credits.json")
+    result = self.cl.transfer_credits(200, False)
+    self.assertEquals(result.AccountCredits, 800)
+    self.assertEquals(result.ClientCredits, 200)
+
   def test_people(self):
- 	self.cl.stub_request("clients/%s/people.json" % self.cl.client_id, "people.json")
- 	people = self.cl.people()
- 	self.assertEquals(2, len(people))
- 	self.assertEquals('person1@blackhole.com', people[0].EmailAddress)
- 	self.assertEquals('Person One', people[0].Name)
- 	self.assertEquals('Active', people[0].Status)  
+    self.cl.stub_request("clients/%s/people.json" % self.cl.client_id, "people.json")
+    people = self.cl.people()
+    self.assertEquals(2, len(people))
+    self.assertEquals('person1@blackhole.com', people[0].EmailAddress)
+    self.assertEquals('Person One', people[0].Name)
+    self.assertEquals('Active', people[0].Status)  
 
   def test_get_primary_contact(self):
   	self.cl.stub_request("clients/%s/primarycontact.json" % self.cl.client_id, "client_get_primary_contact.json")
